@@ -481,10 +481,10 @@ class opensshStatus(StatusMenuItem):
         self.sshRunning = int(getoutput("ps aux | grep -c /usr/sbin/sshd")) - 2
         
     def sshUsers(self):
-        self.sshConnected = int(getoutput("netstat -t | grep -c :ssh[[:space:]]*[0-9].*ESTABLISHED"))
+        self.sshConnected = int(getoutput("netstat -t | grep -cE :ssh[[:space:]]*E{0}.*ESTABLISHED"))
         
     def sshAllUsers(self):
-        self.sshConnected = int(getoutput("netstat -t | grep -c :ssh[[:space:]]*[0-9].*ESTABLISHED"))
+        self.sshConnected = int(getoutput("netstat -t | grep -cE :ssh[[:space:]]*E{0}.*ESTABLISHED"))
         sshNetstat = getoutput("netstat -t | grep :ssh.*ESTABLISHED").split("\n")
         
         countInWLAN = 0
@@ -535,6 +535,10 @@ class opensshStatus(StatusMenuItem):
         
         countInOther = self.sshConnected - countInWLAN - countInUSB
         countOutOther = len(sshNetstat) - self.sshConnected - countOutWLAN - countOutUSB
+        if countInOther < 0:
+            countInOther = 0
+        if countOutOther < 0:
+            countOutOther = 0
         
         if countInOther:
             if countInOther != self.labelCountInOther:
